"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const uuid_1 = require("uuid");
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
class AdRecord {
    constructor(ad) {
        var _a;
        AdRecord.validate(ad);
        this.id = (_a = ad.id) !== null && _a !== void 0 ? _a : (0, uuid_1.v4)();
        this.name = ad.name;
        this.description = ad.description;
        this.price = ad.price;
        this.url = ad.url;
        this.lat = ad.lat;
        this.lon = ad.lon;
    }
    static validate(ad) {
        if (!ad.name || ad.name.trim().length < 1 || ad.name.trim().length > 100) {
            throw new errors_1.ValidationError('Nazwa ogłoszenia musi zawierać od 1 do 100 znaków');
        }
        if (ad.description.trim().length > 1000) {
            throw new errors_1.ValidationError('Opis ogłoszenia nie może przekraczać 1000 znaków');
        }
        if (ad.price < 0 || ad.price > 9999999) {
            throw new errors_1.ValidationError('Cena musi być większa od 0 ale nie może przekraczać 9 999 999');
        }
        if (!ad.url || ad.url.trim().length > 300) {
            throw new errors_1.ValidationError('Link do ogłoszenia nie moze być pusty ani przekraczać 300 znaków');
        }
        if (typeof ad.lat !== 'number' || typeof ad.lon !== 'number') {
            throw new errors_1.ValidationError('Nie można zlokalizować ogłoszenia');
        }
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute('SELECT * FROM `ads` WHERE `id` = :id', {
                id,
            });
            return result.length !== 0 ? new AdRecord(result[0]) : null;
        });
    }
    static getAll(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT  `id`,  `lat`, `lon` FROM `ads` WHERE  `name` LIKE :name', {
                name: `%${name}%`,
            });
            return results;
        });
    }
    save() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('INSERT INTO `ads`(`id`, `name`, `description`, `price`, `url`, `lat`, `lon`) VALUES (:id, :name, :description, :price, :url, :lat, :lon)', {
                id: this.id,
                name: this.name,
                description: this.description,
                price: this.price,
                url: this.url,
                lat: this.lat,
                lon: this.lon,
            });
            return this.id;
        });
    }
    remove() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `ads` WHERE  `id`=:id', {
                id: this.id,
            });
        });
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad.record.js.map