"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_record_1 = require("../records/ad.record");
const db_1 = require("../utils/db");
let newAd;
const newAdId = '456';
beforeAll(() => {
    newAd = new ad_record_1.AdRecord({
        id: newAdId,
        name: 'test2',
        description: 'desc',
        price: 1,
        lat: 12.3232,
        url: 'https://localhost:3000',
        lon: 123.422,
    });
});
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('AdRecord returns data from database for one entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('123');
    expect(ad).toBeDefined();
    expect(ad.id).toBe('123');
    expect(ad.name).toBe('test');
    expect(ad.description).toBe('testowy opis');
    expect(ad.price).toBe(0.00);
    expect(ad.url).toBe('https://megak.pl');
    expect(ad.lat).toBe(50.2657152);
    expect(ad.lon).toBe(18.9945008);
    expect(ad).toBeInstanceOf(ad_record_1.AdRecord);
}));
test('AdRecord return null from database unexsisting entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('zzz');
    expect(ad).toBeNull();
}));
test('Find all Ads and return only id and lat & lon', () => __awaiter(void 0, void 0, void 0, function* () {
    const allAd = yield ad_record_1.AdRecord.getAll('');
    allAd.forEach((ad) => {
        expect(ad).toBeDefined();
        expect(ad.id).toBeDefined();
        expect(ad.lat).toBeDefined();
        expect(ad.lon).toBeDefined();
    });
}));
test('Add record should be added to db', () => __awaiter(void 0, void 0, void 0, function* () {
    const id = yield newAd.save();
    const checkAdInDb = yield ad_record_1.AdRecord.getOne(newAdId);
    expect(checkAdInDb).toEqual({
        id: newAdId,
        name: 'test2',
        description: 'desc',
        price: 1,
        lat: 12.3232,
        url: 'https://localhost:3000',
        lon: 123.422,
    });
    expect(id).toBe(newAdId);
}));
test('Remove Ad  should remove ad from db', () => __awaiter(void 0, void 0, void 0, function* () {
    yield newAd.remove();
    const checkAdInDb = (yield ad_record_1.AdRecord.getOne('456'));
    expect(checkAdInDb).toBeNull();
}));
//# sourceMappingURL=ad.test.js.map